==> vaadin-details-1.1.0.jar: META-INF/resources/webjars/vaadin-details/README.md <==
# &lt;vaadin-details&gt;

[&lt;vaadin-details&gt;](https://vaadin.com/components/vaadin-details) is a Web Component providing functionality for expandable details, part of the [Vaadin components](https://vaadin.com/components).

[Live Demo ↗](https://vaadin.com/components/vaadin-details/html-examples)
|
[API documentation ↗](https://vaadin.com/components/vaadin-details/html-api)

[![npm version](https://badgen.net/npm/v/@vaadin/vaadin-details)](https://www.npmjs.com/package/@vaadin/vaadin-details)
[![Bower version](https://badgen.net/github/release/vaadin/vaadin-details)](https://github.com/vaadin/vaadin-details/releases)
[![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/vaadin/vaadin-details)
[![Build Status](https://travis-ci.org/vaadin/vaadin-details.svg?branch=master)](https://travis-ci.org/vaadin/vaadin-details)
[![Coverage Status](https://coveralls.io/repos/github/vaadin/vaadin-details/badge.svg?branch=master)](https://coveralls.io/github/vaadin/vaadin-details?branch=master)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/vaadin/web-components?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Published on Vaadin Directory](https://img.shields.io/badge/Vaadin%20Directory-published-00b4f0.svg)](https://vaadin.com/directory/component/vaadinvaadin-details)
[![Stars on vaadin.com/directory](https://img.shields.io/vaadin-directory/star/vaadin-details-directory-urlidentifier.svg)](https://vaadin.com/directory/component/vaadinvaadin-details)
<!--
```
<custom-element-demo>
  <template>
    <script src="../webcomponentsjs/webcomponents-lite.js"></script>
    <link rel="import" href="vaadin-details.html">
    <next-code-block></next-code-block>
  </template>
</custom-element-demo>
```
-->
```html
<vaadin-details opened>
  <div slot="summary">Expandable Details</div>
  Toggle using mouse, Enter and Space keys.
</vaadin-details>
```

[<img src="https://raw.githubusercontent.com/vaadin/vaadin-details/master/screenshot.png" alt="Screenshot of vaadin-details" width="320">](https://vaadin.com/components/vaadin-details)


## Installation

The Vaadin components are distributed as Bower and npm packages.
Please note that the version range is the same, as the API has not changed.
You should not mix Bower and npm versions in the same application, though.

Unlike the official Polymer Elements, the converted Polymer 3 compatible Vaadin components
are only published on npm, not pushed to GitHub repositories.

### Polymer 2 and HTML Imports compatible version

Install `vaadin-details`:

```sh
bower i vaadin/vaadin-details --save
```

Once installed, import it in your application:

```html
<link rel="import" href="bower_components/vaadin-details/vaadin-details.html">
```

### Polymer 3 and ES Modules compatible version


Install `vaadin-details`:

```sh
npm i @vaadin/vaadin-details --save
```

Once installed, import it in your application:

```js
import '@vaadin/vaadin-details/vaadin-details.js';
```

## Getting started

Vaadin components use the Lumo theme by default.

To use the Material theme, import the correspondent file from the `theme/material` folder.

## Entry points

- The component with the Lumo theme:

  `theme/lumo/vaadin-details.html`

- The component with the Material theme:

  `theme/material/vaadin-details.html`

- Alias for `theme/lumo/vaadin-details.html`:

  `vaadin-details.html`


## Running demos and tests in a browser

1. Fork the `vaadin-details` repository and clone it locally.

1. Make sure you have [npm](https://www.npmjs.com/) and [Bower](https://bower.io) installed.

1. When in the `vaadin-details` directory, run `npm install` and then `bower install` to install dependencies.

1. Make sure you have [polymer-cli](https://www.npmjs.com/package/polymer-cli) installed globally: `npm i -g polymer-cli`.

1. Run `npm start`, browser will automatically open the component API documentation.

1. You can also open demo or in-browser tests by adding **demo** or **test** to the URL, for example:

  - http://127.0.0.1:3000/components/vaadin-details/demo
  - http://127.0.0.1:3000/components/vaadin-details/test


## Running tests from the command line

1. When in the `vaadin-details` directory, run `polymer test`


## Following the coding style

We are using [ESLint](http://eslint.org/) for linting JavaScript code. You can check if your code is following our standards by running `npm run lint`, which will automatically lint all `.js` files as well as JavaScript snippets inside `.html` files.


## Big Thanks

Cross-browser Testing Platform and Open Source <3 Provided by [Sauce Labs](https://saucelabs.com).


## Contributing

To contribute to the component, please read [the guideline](https://github.com/vaadin/vaadin-core/blob/master/CONTRIBUTING.md) first.


## License

Apache License 2.0

Vaadin collects development time usage statistics to improve this product. For details and to opt-out, see https://github.com/vaadin/vaadin-usage-statistics.

==> vaadin-details-1.2.1.jar: META-INF/resources/webjars/vaadin-details/README.md <==
# &lt;vaadin-details&gt;

> ⚠️ Starting from Vaadin 20, the source code and issues for this component are migrated to the [`vaadin/web-components`](https://github.com/vaadin/web-components/tree/master/packages/vaadin-details) monorepository.
> This repository contains the source code and releases of `<vaadin-details>` for the Vaadin versions 10 to 19.

[&lt;vaadin-details&gt;](https://vaadin.com/components/vaadin-details) is a Web Component providing functionality for expandable details, part of the [Vaadin components](https://vaadin.com/components).

[Live Demo ↗](https://vaadin.com/components/vaadin-details/html-examples)
|
[API documentation ↗](https://vaadin.com/components/vaadin-details/html-api)

[![npm version](https://badgen.net/npm/v/@vaadin/vaadin-details)](https://www.npmjs.com/package/@vaadin/vaadin-details)
[![Bower version](https://badgen.net/github/release/vaadin/vaadin-details)](https://github.com/vaadin/vaadin-details/releases)
[![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/vaadin/vaadin-details)
[![Build Status](https://travis-ci.org/vaadin/vaadin-details.svg?branch=master)](https://travis-ci.org/vaadin/vaadin-details)
[![Coverage Status](https://coveralls.io/repos/github/vaadin/vaadin-details/badge.svg?branch=master)](https://coveralls.io/github/vaadin/vaadin-details?branch=master)
[![Published on Vaadin Directory](https://img.shields.io/badge/Vaadin%20Directory-published-00b4f0.svg)](https://vaadin.com/directory/component/vaadinvaadin-details)
[![Stars on vaadin.com/directory](https://img.shields.io/vaadin-directory/star/vaadin-details-directory-urlidentifier.svg)](https://vaadin.com/directory/component/vaadinvaadin-details)
<!--
```
<custom-element-demo>
  <template>
    <script src="../webcomponentsjs/webcomponents-lite.js"></script>
    <link rel="import" href="vaadin-details.html">
    <next-code-block></next-code-block>
  </template>
</custom-element-demo>
```
-->
```html
<vaadin-details opened>
  <div slot="summary">Expandable Details</div>
  Toggle using mouse, Enter and Space keys.
</vaadin-details>
```

[<img src="https://raw.githubusercontent.com/vaadin/vaadin-details/master/screenshot.png" alt="Screenshot of vaadin-details" width="320">](https://vaadin.com/components/vaadin-details)


## Installation

The Vaadin components are distributed as Bower and npm packages.
Please note that the version range is the same, as the API has not changed.
You should not mix Bower and npm versions in the same application, though.

Unlike the official Polymer Elements, the converted Polymer 3 compatible Vaadin components
are only published on npm, not pushed to GitHub repositories.

### Polymer 2 and HTML Imports compatible version

Install `vaadin-details`:

```sh
bower i vaadin/vaadin-details --save
```

Once installed, import it in your application:

```html
<link rel="import" href="bower_components/vaadin-details/vaadin-details.html">
```

### Polymer 3 and ES Modules compatible version


Install `vaadin-details`:

```sh
npm i @vaadin/vaadin-details --save
```

Once installed, import it in your application:

```js
import '@vaadin/vaadin-details/vaadin-details.js';
```

## Getting started

Vaadin components use the Lumo theme by default.

To use the Material theme, import the correspondent file from the `theme/material` folder.

## Entry points

- The component with the Lumo theme:

  `theme/lumo/vaadin-details.html`

- The component with the Material theme:

  `theme/material/vaadin-details.html`

- Alias for `theme/lumo/vaadin-details.html`:

  `vaadin-details.html`


## Running demos and tests in a browser

1. Fork the `vaadin-details` repository and clone it locally.

1. Make sure you have [npm](https://www.npmjs.com/) and [Bower](https://bower.io) installed.

1. When in the `vaadin-details` directory, run `npm install` and then `bower install` to install dependencies.

1. Make sure you have [polymer-cli](https://www.npmjs.com/package/polymer-cli) installed globally: `npm i -g polymer-cli`.

1. Run `npm start`, browser will automatically open the component API documentation.

1. You can also open demo or in-browser tests by adding **demo** or **test** to the URL, for example:

  - http://127.0.0.1:3000/components/vaadin-details/demo
  - http://127.0.0.1:3000/components/vaadin-details/test


## Running tests from the command line

1. When in the `vaadin-details` directory, run `polymer test`


## Following the coding style

We are using [ESLint](http://eslint.org/) for linting JavaScript code. You can check if your code is following our standards by running `npm run lint`, which will automatically lint all `.js` files as well as JavaScript snippets inside `.html` files.


## Big Thanks

Cross-browser Testing Platform and Open Source <3 Provided by [Sauce Labs](https://saucelabs.com).


## Contributing

To contribute to the component, please read [the guideline](https://github.com/vaadin/vaadin-core/blob/master/CONTRIBUTING.md) first.


## License

Apache License 2.0

Vaadin collects development time usage statistics to improve this product. For details and to opt-out, see https://github.com/vaadin/vaadin-usage-statistics.
